@@ -8,17 +8,19 @@ from .yandex import YandexTranslator
 from .qcri import QCRI
 from .deepl import DeepL
 from .detection import single_detection, batch_detection
+from .microsoft import MicrosoftTranslator
 
 
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.3.4'
+__version__ = '1.3.5'
 
 __all__ = [GoogleTranslator,
            PonsTranslator,
            LingueeTranslator,
            MyMemoryTranslator,
            YandexTranslator,
+           MicrosoftTranslator,
            QCRI,
            DeepL,
            single_detection,
