@@ -81,6 +81,19 @@ class RequestError(Exception):
         return self.message
 
 
+class MicrosoftAPIerror(Exception):
+    """
+    exception thrown if Microsoft API returns one of its errors
+    """
+
+    def __init__(self, api_message):
+        self.api_message = str(api_message)
+        self.message="Microsoft API returned the following error"
+
+    def __str__(self):
+        return "{}: {}".format(self.message, self.api_message)
+
+
 class TooManyRequests(Exception):
     """
     exception thrown if an error occured during the request call, e.g a connection problem.
