@@ -105,7 +105,7 @@ class GoogleTranslator(BaseTranslator):
                 element = soup.find(self._element_tag, self._alt_element_query)
                 if not element:
                     raise TranslationNotFound(text)
-            if element.get_text(strip=True) == text:
+            if element.get_text(strip=True) == text.strip() and text.strip().replace(' ', '').isalpha():
                 self._url_params["tl"] = self._target
                 del self._url_params["hl"]
                 return self.translate(text)
@@ -173,5 +173,5 @@ class GoogleTranslator(BaseTranslator):
 
 if __name__ == '__main__':
 
-    txt =GoogleTranslator(source='en', target='nl').translate('why not Dutch') # GoogleTranslator(source='hindi', target='en').translate(text="ghar jaana hai")
+    txt =GoogleTranslator(source='en', target='nl').translate('why not dutch') # GoogleTranslator(source='hindi', target='en').translate(text="ghar jaana hai")
     print("text: ", txt)
